//-*-C++-*- Header file for the Program Class
// Copyright (C) 1997 by John P. Weiss
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Artistic License, included as the file
// "LICENSE" in the source code archive.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
// You should have received a copy of the file "LICENSE", containing
// the License John Weiss originally placed this program under.
//
// This file is unreadable, because the comment-docifier is
// brainedead.  Try a "make srcdocs" to generate the
// HTML-documentation.
//
#ifndef _Program_h_
#define _Program_h_
#include "AudioDev.h"
#include "APDialog.h"
#include <qlabel.h>
#include <qlistbox.h>
#include <qpushbt.h>

//
#define STYLEFLAGS WStyle_Customize|WStyle_Title|WStyle_SysMenu


/**
  An \Ref{APDialog} for creating custom programs.  It directly alters
  the \Ref{playlist} member of the \Ref{Catalog} object belonging to
  the specified \Ref{AudioDev}.

  The private members and methods are not documented; they exist
  solely to support the dialog box used to do the editing.

  @memo Creates programs.
  @see Catalog, AudioDev
  */
class Program : public APDialog
{
	 //
	 Q_OBJECT

   public:
	 /**
	   Class Constructor.  Requires an \Ref{AudioDev} pointer, from
	   which it gets the \Ref{Catalog} object to change.
	   @memo
	   */
	 Program( AudioDev *devname );

	 /**
	   Class Destructor.
	   @memo
	   */
	 ~Program( void );


	 //
   public slots:
      /** 
	   {\em Public Slot} {\tt [virtual]}

	   Reimplemented from \Ref{APDialog}.  Calls the \Ref{AudioDev}'s
	   \Ref{newProgram}() method to implement any changes to the
	   \Ref{Catalog}'s \Ref{playlist}.
	   @memo [{\tt virtual public slot}]
	   */
	 void open();


   private:
	 QListBox *tracks, *newprog;
	 QPushButton *moveb;
	 AudioDev *dev;
	 bool isMoving;
	 int moveThis;
	 //
	 void createChildren(QFont& dffont);
	 void startProg();

   private slots:
	 //
	 void delProgItem();
	 void moveProgItem();
	 void endMove(int);
	 void clearMove(int);
	 void moveToEnd();
	 void addProgItem();
	 void addProgItem(int);
	 void clearProg();
};

#endif // _Program_h_
/////////////////////////////////
//
// End
// 

